DefaultDateOption enum

Inheritance
Available extensions

Values

none → const DefaultDateOption
const DefaultDateOption('none')
today → const DefaultDateOption
const DefaultDateOption('today')
now → const DefaultDateOption
const DefaultDateOption('now')
specific → const DefaultDateOption
const DefaultDateOption('specific')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String json) DefaultDateOption

Constants

values → const List<DefaultDateOption>
A constant List of the values in this enum, in order of their declaration.