StudySchedule class

Annotations
  • @JsonSerializable.new()

Constructors

StudySchedule({String sequenceCustom = 'ABAB'})
StudySchedule.fromJson(Map<String, dynamic> json)
factory

Properties

baselineLength → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
includeBaseline ↔ bool
getter/setter pair
length → int
no setter
nameOfSequence → String
no setter
numberOfCycles ↔ int
getter/setter pair
numberOfPhases → int
no setter
phaseDuration ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ PhaseSequence
getter/setter pair
sequenceCustom ↔ String
getter/setter pair

Methods

generateInterventionIdsInOrder(List<String> interventionsIds) → List<String>
generateWith(int firstIntervention) → List<int>
getNumberOfPhases() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

numberOfInterventions → const int