TimeFormatPreset enum

Inheritance
Available extensions

Values

h24 → const TimeFormatPreset
const TimeFormatPreset('HH:mm')
h12 → const TimeFormatPreset
const TimeFormatPreset('hh:mm a')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
is24Hour bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pattern String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String json) TimeFormatPreset

Constants

values → const List<TimeFormatPreset>
A constant List of the values in this enum, in order of their declaration.