DateQuestion class
Constructors
- DateQuestion({DateInputType inputType = DateInputType.date, DateTime? minDate, DateTime? maxDate, String? minTime, String? maxTime, DateFormatPreset dateFormatPreset = DateFormatPreset.iso, TimeFormatPreset timeFormatPreset = TimeFormatPreset.h24, DefaultDateOption defaultOption = DefaultDateOption.none, DateTime? defaultSpecificDate, String? defaultSpecificTime})
-
DateQuestion.fromJson(Map<
String, dynamic> json) -
factory
- DateQuestion.withId({DateInputType inputType = DateInputType.date, DateTime? minDate, DateTime? maxDate, String? minTime, String? maxTime, DateFormatPreset dateFormatPreset = DateFormatPreset.iso, TimeFormatPreset timeFormatPreset = TimeFormatPreset.h24, DefaultDateOption defaultOption = DefaultDateOption.none, DateTime? defaultSpecificDate, String? defaultSpecificTime})
Properties
-
conditional
↔ QuestionConditional<
DateTime> ? -
getter/setter pairinherited
- dateFormat → String
-
no setter
- dateFormatPreset ↔ DateFormatPreset
-
getter/setter pair
- defaultOption ↔ DefaultDateOption
-
getter/setter pair
- defaultSpecificDate ↔ DateTime?
-
getter/setter pair
- defaultSpecificTime ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pairinherited
- inputType ↔ DateInputType
-
getter/setter pair
- isDate → bool
-
no setter
- isDateOnly → bool
-
no setter
- isDateTime → bool
-
no setter
- isTime → bool
-
no setter
- isTimeOnly → bool
-
no setter
- maxDate ↔ DateTime?
-
getter/setter pair
- maxTime ↔ String?
-
getter/setter pair
- minDate ↔ DateTime?
-
getter/setter pair
- minTime ↔ String?
-
getter/setter pair
- prompt ↔ String?
-
getter/setter pairinherited
- rationale ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeFormat → String
-
no setter
- timeFormatPreset ↔ TimeFormatPreset
-
getter/setter pair
- type ↔ String
-
getter/setter pairinherited
Methods
-
constructAnswer(
DateTime response) → Answer< DateTime> -
getAnswerType(
) → Type -
inherited
-
getDefaultAnswer(
) → Answer< DateTime> ? -
inherited
-
getDefaultValue(
) → DateTime? -
getInitialTimeValue(
) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldBeShown(
QuestionnaireState state) → bool -
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- questionType → const String